Learn R Programming

campsis (version 1.9.0)

.auto_colour_columns: Detect colour stratification columns automatically.

Description

Adds "ARM" when the column exists and contains more than one distinct value. Same logic for "SCENARIO".

Usage

.auto_colour_columns(x)

Value

a character vector of column names to colour by, or NULL

Arguments

x

a data frame (typically std_campsis_tbl)