BootstrapDistribution: Create a bootstrap distribution. During function sampling,...

View source: R/distribution.R

BootstrapDistributionR Documentation

Create a bootstrap distribution. During function sampling, Campsis will generate values depending on the given data and arguments.

Description

Create a bootstrap distribution. During function sampling, Campsis will generate values depending on the given data and arguments.

Usage

BootstrapDistribution(data, replacement = FALSE, random = FALSE)

Arguments

data

values to draw, numeric vector

replacement

values can be reused or not, logical

random

values are drawn randomly, logical

Value

a bootstrap distribution


campsis documentation built on Aug. 5, 2026, 9:07 a.m.