apply_compartment_characteristics: Apply compartment characteristics from model. In practice,...

View source: R/dataset.R

apply_compartment_characteristicsR Documentation

Apply compartment characteristics from model. In practice, only compartment infusion duration needs to be applied.

Description

Apply compartment characteristics from model. In practice, only compartment infusion duration needs to be applied.

Usage

apply_compartment_characteristics(table, properties)

Arguments

table

current dataset

properties

compartment properties from model

Value

updated dataset


campsis documentation built on Aug. 5, 2026, 9:07 a.m.