convertTime: Convert numeric time vector based on the provided units.

View source: R/deprecated_methods.R

convertTimeR Documentation

Convert numeric time vector based on the provided units.

Description

'r lifecycle::badge("deprecated")'

Usage

convertTime(x, from, to)

Arguments

x

numeric time vector

from

unit of x, single character value

to

destination unit, single character value

Details

'convertTime()' is deprecated in favor of 'convert_time()'.

Value

numeric vector with the converted times


campsis documentation built on Aug. 5, 2026, 9:07 a.m.