Learn R Programming

campsis (version 1.9.0)

convert_time: Convert numeric time vector based on the provided units.

Description

Convert numeric time vector based on the provided units.

Usage

convert_time(x, from, to)

Value

numeric vector with the converted times

Arguments

x

numeric time vector

from

unit of x, single character value

to

destination unit, single character value