dot-assert_variable_present: Assert that one or more variable columns are present in the...

.assert_variable_presentR Documentation

Assert that one or more variable columns are present in the data.

Description

Raises an informative error listing all absent column names.

Usage

.assert_variable_present(x, variable)

Arguments

x

a data frame

variable

character vector of column name(s) to check

Value

invisibly NULL; called for its side-effect


campsis documentation built on Aug. 5, 2026, 9:07 a.m.