| .auto_colour_columns | R Documentation |
Adds "ARM" when the column exists and contains more than one distinct
value. Same logic for "SCENARIO".
.auto_colour_columns(x)
x |
a data frame (typically |
a character vector of column names to colour by, or NULL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.