drop_others: Return the 'DROP_OTHERS' string that may be used in the...

View source: R/simulate_preprocess.R

drop_othersR Documentation

Return the 'DROP_OTHERS' string that may be used in the 'outvars' vector for RxODE/mrgsolve to drop all others variables that are usually output in the resulting data frame.

Description

Return the 'DROP_OTHERS' string that may be used in the 'outvars' vector for RxODE/mrgsolve to drop all others variables that are usually output in the resulting data frame.

Usage

drop_others()

Value

a character value


campsis documentation built on Aug. 5, 2026, 9:07 a.m.