get_column: Get data of given column unless if does not exist (return...

View source: R/default_plot.R

get_columnR Documentation

Get data of given column unless if does not exist (return NULL in that case).

Description

Get data of given column unless if does not exist (return NULL in that case).

Usage

get_column(.data, colname)

Arguments

.data

data frame

colname

column name

Value

a vector


campsis documentation built on Aug. 5, 2026, 9:07 a.m.