get_compartment_mapping: Get a mapping table with all possibilities of compartment...

View source: R/dataset.R

get_compartment_mappingR Documentation

Get a mapping table with all possibilities of compartment names and their indexes knowing that compartment names can be provided as character or as integer.

Description

Get a mapping table with all possibilities of compartment names and their indexes knowing that compartment names can be provided as character or as integer.

Usage

get_compartment_mapping(compartments)

Arguments

compartments

list of compartments

Value

a tibble with two columns: INDEX and NAME


campsis documentation built on Aug. 5, 2026, 9:07 a.m.