get_times: Get all distinct times for the specified object.

View source: R/generic.R

get_timesR Documentation

Get all distinct times for the specified object.

Description

Get all distinct times for the specified object.

Usage

get_times(object, ...)

## S4 method for signature 'treatment'
get_times(object, unwrap = TRUE)

## S4 method for signature 'observations'
get_times(object, doseTimes = NULL)

## S4 method for signature 'observations_set'
get_times(object, doseTimes = NULL)

## S4 method for signature 'arm'
get_times(object)

## S4 method for signature 'arms'
get_times(object)

## S4 method for signature 'events'
get_times(object)

## S4 method for signature 'dataset'
get_times(object)

Arguments

object

any object

...

extra arguments like 'doseTimes' in observations or 'unwrap' in treatment

unwrap

unwrap treatment before accessing the times, default value is TRUE

doseTimes

times of the doses, only needed if a [DosingSchedule()] is referred to

Value

numeric vector with all unique times, sorted


campsis documentation built on Aug. 5, 2026, 9:07 a.m.