on_cran: Check if the current session is on CRAN. The objective is to...

View source: R/utilities.R

on_cranR Documentation

Check if the current session is on CRAN. The objective is to potentially suppress long tasks to be run on CRAN (long tests or vignettes).

Description

Check if the current session is on CRAN. The objective is to potentially suppress long tasks to be run on CRAN (long tests or vignettes).

Usage

on_cran()

Value

logical value TRUE/FALSE


campsis documentation built on Aug. 5, 2026, 9:07 a.m.