preprocess_dest: Pre-process destination engine. Throw an error message if the...

View source: R/simulate_preprocess.R

preprocess_destR Documentation

Pre-process destination engine. Throw an error message if the destination engine is not installed.

Description

Pre-process destination engine. Throw an error message if the destination engine is not installed.

Usage

preprocess_dest(dest)

Arguments

dest

destination engine (from simulate argument, default settings or S4 simulation engine)

Value

'rxode2' or 'mrgsolve'


campsis documentation built on Aug. 5, 2026, 9:07 a.m.