preprocess_outvars: Preprocess 'outvars' argument. 'Outvars' is a character...

View source: R/simulate_preprocess.R

preprocess_outvarsR Documentation

Preprocess 'outvars' argument. 'Outvars' is a character vector which tells Campsis the mandatory columns to keep in the output dataframe.

Description

Preprocess 'outvars' argument. 'Outvars' is a character vector which tells Campsis the mandatory columns to keep in the output dataframe.

Usage

preprocess_outvars(outvars)

Arguments

outvars

character vector or function

Value

outvars


campsis documentation built on Aug. 5, 2026, 9:07 a.m.