| process_arm_labels | R Documentation |
Process arm labels. Arm identifiers in ARM column are replaced by arm labels as soon as one arm label is provided.
process_arm_labels(campsis, arms)
campsis |
Campsis output |
arms |
all treatment arms |
updated Campsis output with arm labels instead of arm identifiers
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.