set_seed: Set the seed. The goal of this method is to centralize all...

View source: R/seed.R

set_seedR Documentation

Set the seed. The goal of this method is to centralize all calls to the R method 'set.seed'.

Description

Set the seed. The goal of this method is to centralize all calls to the R method 'set.seed'.

Usage

set_seed(seed)

Arguments

seed

seed value, not NULL


campsis documentation built on Aug. 5, 2026, 9:07 a.m.