setupPlanDefault: Setup default plan for the given simulation or hardware...

View source: R/deprecated_methods.R

setupPlanDefaultR Documentation

Setup default plan for the given simulation or hardware settings. This plan will prioritise the distribution of workers in the following order: 1) Replicates (if 'replicate_parallel' is enabled) 2) Scenarios (if 'scenario_parallel' is enabled) 3) Dataset export / slices (if 'dataset_export' or 'slice_parallel' is enabled)

Description

'r lifecycle::badge("deprecated")'

Usage

setupPlanDefault(object)

Arguments

object

simulation or hardware settings

Details

'setupPlanDefault()' is deprecated in favor of 'setup_plan_default()'.

Value

nothing


campsis documentation built on Aug. 5, 2026, 9:07 a.m.