undefined_distribution-class: Undefined distribution class. This type of object is...

undefined_distribution-classR Documentation

Undefined distribution class. This type of object is automatically created in method to_explicit_distribution() when the user does not provide a concrete distribution. This is because S4 objects do not accept NULL values.

Description

Undefined distribution class. This type of object is automatically created in method to_explicit_distribution() when the user does not provide a concrete distribution. This is because S4 objects do not accept NULL values.


campsis documentation built on Aug. 5, 2026, 9:07 a.m.