.assert_variable_present: Assert that one or more variable columns are present in the data.
Description
Raises an informative error listing all absent column names.
Usage
.assert_variable_present(x, variable)
Value
invisibly NULL; called for its side-effect
Arguments
- x
a data frame
- variable
character vector of column name(s) to check