powered by
Adds "ARM" when the column exists and contains more than one distinct value. Same logic for "SCENARIO".
"ARM"
"SCENARIO"
.auto_colour_columns(x)
a character vector of column names to colour by, or NULL
NULL
a data frame (typically std_campsis_tbl)
std_campsis_tbl