View source: R/deprecated_methods.R
| PI | R Documentation |
Compute the prediction interval summary over time (deprecated).
PI(x, variable, strata = get_default_strata(), level = 0.9)
x |
data frame |
variable |
variable(s) used to compute the prediction interval, character vector.
When more than one variable is supplied, a |
strata |
named vector with the strata to use, default is c(SCENARIO="all", ARM="all").
Only columns that are actually present in |
level |
PI level, default is 0.9 (90% PI) |
a summary table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.