Compute the prediction interval summary over time (deprecated).
PI(x, variable, strata = get_default_strata(), level = 0.9)a summary table
data frame
variable(s) used to compute the prediction interval, character vector.
When more than one variable is supplied, a variable column is added to the
output to identify each one.
named vector with the strata to use, default is c(SCENARIO="all", ARM="all").
Only columns that are actually present in x are used.
PI level, default is 0.9 (90% PI)