apply_compartment_characteristics: Apply compartment characteristics from model.
In practice, only compartment infusion duration needs to be applied.
Description
Apply compartment characteristics from model.
In practice, only compartment infusion duration needs to be applied.
Usage
apply_compartment_characteristics(table, properties)
Arguments
- table
current dataset
- properties
compartment properties from model