Learn R Programming

campsis (version 1.9.0)

get_column: Get data of given column unless if does not exist (return NULL in that case).

Description

Get data of given column unless if does not exist (return NULL in that case).

Usage

get_column(.data, colname)

Value

a vector

Arguments

.data

data frame

colname

column name