Learn R Programming

campsis (version 1.9.0)

get_times: Get all distinct times for the specified object.

Description

Get all distinct times for the specified object.

Usage

get_times(object, ...)

# S4 method for treatment get_times(object, unwrap = TRUE)

# S4 method for observations get_times(object, doseTimes = NULL)

# S4 method for observations_set get_times(object, doseTimes = NULL)

# S4 method for arm get_times(object)

# S4 method for arms get_times(object)

# S4 method for events get_times(object)

# S4 method for dataset get_times(object)

Value

numeric vector with all unique times, sorted

Arguments

object

any object

...

extra arguments like `doseTimes` in observations or `unwrap` in treatment

unwrap

unwrap treatment before accessing the times, default value is TRUE

doseTimes

times of the doses, only needed if a [DosingSchedule()] is referred to