| outfun-class | R Documentation |
Output function class.
funfunction or purrr-style lambda formula, first argument 'x' must be the results
namename of the output function
argsextra arguments, named list
packagespackages that must be loaded to execute the given function, character vector
leveleither 'scenario' or 'replicate'. Default is 'scenario'.
clsresulting S3 class(es) of the Campsis output
outfun_as_arglogical, whether to pass the outfun object as an argument to the function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.