Learn R Programming

campsis (version 1.9.0)

preprocess_dest: Pre-process destination engine. Throw an error message if the destination engine is not installed.

Description

Pre-process destination engine. Throw an error message if the destination engine is not installed.

Usage

preprocess_dest(dest)

Value

'rxode2' or 'mrgsolve'

Arguments

dest

destination engine (from simulate argument, default settings or S4 simulation engine)