Learn R Programming

campsis (version 1.9.0)

preprocess_outvars: Preprocess 'outvars' argument. 'Outvars' is a character vector which tells Campsis the mandatory columns to keep in the output dataframe.

Description

Preprocess 'outvars' argument. 'Outvars' is a character vector which tells Campsis the mandatory columns to keep in the output dataframe.

Usage

preprocess_outvars(outvars)

Value

outvars

Arguments

outvars

character vector or function