Learn R Programming

campsis (version 1.9.0)

set_seed: Set the seed. The goal of this method is to centralize all calls to the R method 'set.seed'.

Description

Set the seed. The goal of this method is to centralize all calls to the R method 'set.seed'.

Usage

set_seed(seed)

Arguments

seed

seed value, not NULL