| shaded_plot.std_campsis_tbl | R Documentation |
Plots a median line with a prediction interval ribbon from a
std_campsis_tbl (the default output of simulate() when no
custom outfun is used).
## S3 method for class 'std_campsis_tbl'
shaded_plot(
x,
variable = "CONC",
colour = "auto",
strat_extra = NULL,
level = 0.9,
alpha = 0.25,
...
)
x |
a |
variable |
name of the column to summarise on the y-axis. Defaults to
|
colour |
stratification for line and ribbon colour. One of
|
strat_extra |
additional column name(s) used for stratification in the
prediction interval computation but not mapped to colour — useful
when combined with |
level |
prediction interval level. Default is |
alpha |
transparency of the ribbon. Default is |
... |
additional arguments (currently unused, reserved for future use) |
Colour stratification is resolved as follows:
"auto" (default): ARM is added when more than one
distinct arm is detected in the data; SCENARIO is added when
more than one distinct scenario is detected.
NULL: no colour mapping.
character vector: explicit column name(s) to colour/fill by
(forwarded directly to shadedPlot).
a ggplot object
shadedPlot
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.