| vpc_plot.std_campsis_tbl | R Documentation |
Plots VPC ribbons (a confidence interval around the median, lower and upper
percentiles) from a std_campsis_tbl, i.e. the default output of
simulate() with multiple replicates and no custom outfun
(DefaultOutfun). In this case the data contains all
unsummarised individual profiles, so the per-replicate prediction interval
is computed first (the lower/median/upper percentiles of variable
across individuals within each replicate), before the confidence interval
around each percentile is computed across replicates.
## S3 method for class 'std_campsis_tbl'
vpc_plot(
x,
variable = "CONC",
strata = "auto",
pi_level = 0.9,
ci_level = 0.9,
alpha = 0.15,
facet = TRUE,
...
)
x |
a |
variable |
name of the column to summarise on the y-axis. Defaults to
|
strata |
stratification for the VPC. One of |
pi_level |
prediction interval level, i.e. the percentiles of the data
computed within each replicate. Default is |
ci_level |
confidence interval level for the ribbons around each
percentile across replicates. Default is |
alpha |
transparency of the ribbons. Default is |
facet |
how the stratification variable is displayed when present.
|
... |
additional arguments (currently unused, reserved for future use) |
Stratification is resolved as follows:
"auto" (default): ARM is used when more than one
distinct arm is detected; otherwise SCENARIO is used when
more than one distinct scenario is detected; otherwise NULL
(no stratification). Only one stratification variable is applied
because vpcPlot supports at most one.
NULL: no stratification.
named character vector: passed directly to vpcPlot
(e.g. c(ARM = "all") or c(SCENARIO = "all")).
a ggplot object
vpcPlot, vpc_plot.pi_campsis_tbl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.